@@ -20,9 +20,9 @@
 #ifndef TILEDARRAY_TEST_ARRAY_FIXTURE_H__INCLUDED
 #define TILEDARRAY_TEST_ARRAY_FIXTURE_H__INCLUDED
 
+#include "range_fixture.h"
 #include "tiledarray.h"
 #include "unit_test_config.h"
-#include "range_fixture.h"
 
 #include "../src/TiledArray/dist_array.h"
 
@@ -30,18 +30,18 @@ struct ArrayFixture : public TiledRangeFixture {
   typedef TArrayI ArrayN;
   typedef TSpArrayI SpArrayN;
   typedef ArrayN::index index;
-  typedef ArrayN::size_type size_type;
+  typedef ArrayN::ordinal_type size_type;
+  typedef ArrayN::ordinal_type ordinal_type;
   typedef ArrayN::value_type tile_type;
 
   ArrayFixture();
 
   ~ArrayFixture();
 
-
   TiledArray::Tensor<float> shape_tensor;
   TiledArray::World& world;
   ArrayN a;
-}; // struct ArrayFixture
+  SpArrayN b;
+};  // struct ArrayFixture
 
-
-#endif // TILEDARRAY_TEST_ARRAY_FIXTURE_H__INCLUDED
+#endif  // TILEDARRAY_TEST_ARRAY_FIXTURE_H__INCLUDED
