@@ -17,16 +17,26 @@
  *
  */
 
-#define BOOST_TEST_MAIN TiledArray Tests
+#define BOOST_TEST_MODULE TiledArray Tests
+#include <TiledArray/initialize.h>
+#include "TiledArray/external/madness.h"
 #include "unit_test_config.h"
-#include "TiledArray/madness.h"
 
 GlobalFixture::GlobalFixture() {
-  world = & TiledArray::initialize(
+  world = &TiledArray::initialize(
       boost::unit_test::framework::master_test_suite().argc,
       boost::unit_test::framework::master_test_suite().argv);
 
-  world->gop.fence();
+  //  N.B. uncomment to create debugger:
+  // using TiledArray::Debugger;
+  // auto debugger = std::make_shared<Debugger>("ta_test");
+  // Debugger::set_default_debugger(debugger);
+  // debugger->set_prefix(world->rank());
+  // choose lldb or gdb
+  // debugger->set_cmd("lldb_xterm");
+  // debugger->set_cmd("gdb_xterm");
+  // to launch a debugger here or elsewhere:
+  // Debugger::default_debugger()->debug("ready to run");
 }
 
 GlobalFixture::~GlobalFixture() {
@@ -35,9 +45,9 @@ GlobalFixture::~GlobalFixture() {
 }
 
 TiledArray::World* GlobalFixture::world = NULL;
-const std::array<std::size_t, 20> GlobalFixture::primes =
-    {{ 2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61, 67, 71 }};
-
+const std::array<std::size_t, 20> GlobalFixture::primes = {
+    {2,  3,  5,  7,  11, 13, 17, 19, 23, 29,
+     31, 37, 41, 43, 47, 53, 59, 61, 67, 71}};
 
 // This line will initialize mpi and madness.
-BOOST_GLOBAL_FIXTURE( GlobalFixture );
+BOOST_GLOBAL_FIXTURE(GlobalFixture);
